import pandas as pd
import numpy as np

def clean_dataframe(df):
    """Cleans a DataFrame by:
    - Replacing NaN values with 0 for numeric columns (int will get 0, float will get 0.0).
    - Replacing NaN values with '' (empty string) for non-numeric columns.
    - Stripping leading/trailing whitespace from string columns.
    - Replacing spaces in column names with underscores.
    """
    df = df.copy()  # Work on a copy to avoid SettingWithCopyWarning

    # Clean column names
    df.columns = [col.strip().replace(" ", "_") for col in df.columns]

    for col in df.columns:
        if pd.api.types.is_numeric_dtype(df[col]):
            # For numeric columns, fill NaN with 0 (for int) or 0.0 (for float)
            df[col] = df[col].fillna(0) 
            if pd.api.types.is_integer_dtype(df[col]):
                # Ensure integer columns are of integer type
                df[col] = df[col].astype('Int64')  # Int64 for nullable integers
            elif pd.api.types.is_float_dtype(df[col]):
                # Ensure float columns remain float type
                df[col] = df[col].astype('float64')
        else:
            # For non-numeric columns, replace NaN with empty string
            df[col] = df[col].fillna('')

            # Clean leading/trailing spaces in string values
            df[col] = df[col].astype(str).str.strip()

    return df
